@@ -12,13 +12,14 @@ def pytest_addoption(parser: pytest.Parser) -> None:
     parser.addini("env", type="linelist", help=help_msg, default=[])
 
 
-@pytest.hookimpl(tryfirst=True)  # type: ignore # untyped decorator
+@pytest.hookimpl(tryfirst=True)  # type: ignore[misc]
 def pytest_load_initial_conftests(
-    args: list[str], early_config: pytest.Config, parser: pytest.Parser  # noqa: U100
+    args: list[str],  # noqa: ARG001
+    early_config: pytest.Config,
+    parser: pytest.Parser,  # noqa: ARG001
 ) -> None:
     """Load environment variables from configuration files."""
     for line in early_config.getini("env"):
-
         # INI lines e.g. D:R:NAME=VAL has two flags (R and D), NAME key, and VAL value
         parts = line.partition("=")
         ini_key_parts = parts[0].split(":")
